# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cockroachdb_cloud_client',
 'cockroachdb_cloud_client.api',
 'cockroachdb_cloud_client.api.cockroach_cloud',
 'cockroachdb_cloud_client.models']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=21.3.0', 'httpx>=0.15.4,<0.24.0', 'python-dateutil>=2.8.0,<3.0.0']

setup_kwargs = {
    'name': 'cockroachdb-cloud-client',
    'version': '0.0.2',
    'description': 'A client library for accessing CockroachDB Cloud API',
    'long_description': '# cockroachdb_cloud_client\n\nA client library for accessing CockroachDB Cloud API\n\n## Usage\n\nFirst, create a client:\n\n```python\nfrom cockroachdb_cloud_client import Client\n\nclient = Client(base_url="https://api.example.com")\n```\n\nIf the endpoints you\'re going to hit require authentication, use `AuthenticatedClient` instead:\n\n```python\nfrom cockroachdb_cloud_client import AuthenticatedClient\n\nclient = AuthenticatedClient(base_url="https://api.example.com", token="SuperSecretToken")\n```\n\nNow call your endpoint and use your models:\n\n```python\nfrom cockroachdb_cloud_client import AuthenticatedClient\nfrom cockroachdb_cloud_client.models import ListClustersResponse\nfrom cockroachdb_cloud_client.api.cockroach_cloud import cockroach_cloud_list_clusters\nfrom cockroachdb_cloud_client.types import Response\nfrom pprint import pprint\nimport json\n\n\nclient = AuthenticatedClient(base_url="https://cockroachlabs.cloud", token="CC-xxxx-yyyy-zzzz")\n\nresp: Response[ListClustersResponse] = cockroach_cloud_list_clusters.sync_detailed(client=client)\n\npprint(json.loads(resp.content))\n```\n\nBy default, when you\'re calling an HTTPS API it will attempt to verify that SSL is working correctly. Using certificate verification is highly recommended most of the time, but sometimes you may need to authenticate to a server (especially an internal server) using a custom certificate bundle.\n\n```python\nclient = AuthenticatedClient(\n    base_url="https://internal_api.example.com", \n    token="SuperSecretToken",\n    verify_ssl="/path/to/certificate_bundle.pem",\n)\n```\n\nYou can also disable certificate validation altogether, but beware that **this is a security risk**.\n\n```python\nclient = AuthenticatedClient(\n    base_url="https://internal_api.example.com", \n    token="SuperSecretToken", \n    verify_ssl=False\n)\n```\n\nThings to know:\n\n1. Every path/method combo becomes a Python module with four functions:\n    1. `sync`: Blocking request that returns parsed data (if successful) or `None`\n    1. `sync_detailed`: Blocking request that always returns a `Request`, optionally with `parsed` set if the request was successful.\n    1. `asyncio`: Like `sync` but async instead of blocking\n    1. `asyncio_detailed`: Like `sync_detailed` but async instead of blocking\n\n1. All path/query params, and bodies become method arguments.\n1. If your endpoint had any tags on it, the first tag will be used as a module name for the function (my_tag above)\n1. Any endpoint which did not have a tag will be in `cockroachdb_cloud_client.api.default`\n',
    'author': 'Cockroach Labs',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
